"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _TabBarItem = _interopRequireDefault(require("./TabBarItem"));

var _Theme = require("../../core/Theme");

var _reactNativeIphoneXHelper = require("react-native-iphone-x-helper");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const TabBar = ({
  theme,
  state,
  descriptors,
  navigation
}) => {
  const [translateValue] = (0, _react.useState)(new _reactNative.Animated.Value(0));

  const totalWidth = _reactNative.Dimensions.get('window').width;

  const tabWidth = totalWidth / state.routes.length;
  const tabBarStyleHeigth = {
    height: _reactNative.Platform.OS === 'ios' ? 50 : 45
  };

  if ((0, _reactNativeIphoneXHelper.isIphoneX)()) {
    tabBarStyleHeigth.height = 70;
  }

  const animateLine = index => {
    _reactNative.Animated.spring(translateValue, {
      toValue: index * tabWidth,
      velocity: 10,
      useNativeDriver: true
    }).start();
  };

  (0, _react.useEffect)(() => {
    animateLine(state.index);
  }, [state.index]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [style.tabContainer, tabBarStyleHeigth, {
      width: totalWidth,
      backgroundColor: theme.colors.surface
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flexDirection: 'row'
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [style.slider, {
      backgroundColor: theme.colors.primary
    }, {
      transform: [{
        translateX: translateValue
      }],
      width: tabWidth - 60
    }]
  }), state.routes.map((route, index) => {
    const {
      options
    } = descriptors[route.key];
    const label = options.tabBarLabel !== undefined ? options.tabBarLabel : options.title !== undefined ? options.title : route.name;
    const isFocused = state.index === index;

    const onPress = () => {
      const event = navigation.emit({
        type: 'tabPress',
        target: route.key,
        canPreventDefault: true
      });

      if (!isFocused && !event.defaultPrevented) {
        navigation.navigate(route.name);
      }

      animateLine(index);
    };

    const onLongPress = () => {
      navigation.emit({
        type: 'tabLongPress',
        target: route.key
      });
    };

    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      accessibilityRole: "button",
      accessibilityState: isFocused ? {
        selected: true
      } : {},
      accessibilityLabel: options.tabBarAccessibilityLabel,
      testID: options.tabBarTestID,
      onPress: onPress,
      onLongPress: onLongPress,
      style: {
        flex: 1
      },
      key: index
    }, /*#__PURE__*/_react.default.createElement(_TabBarItem.default, {
      iconName: label.toString(),
      isCurrent: isFocused
    }));
  })));
};

var _default = (0, _Theme.withTheme)(TabBar);

exports.default = _default;

const style = _reactNative.StyleSheet.create({
  tabContainer: {
    shadowOffset: {
      width: 0,
      height: -1
    },
    borderTopColor: 'gray',
    shadowOpacity: 0.1,
    shadowRadius: 4.0,
    elevation: 10,
    position: 'absolute',
    bottom: 0
  },
  slider: {
    height: 2.5,
    position: 'absolute',
    top: 0,
    left: 30,
    borderRadius: 10
  }
});
//# sourceMappingURL=TabBar.js.map