"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeNoxi = require("react-native-noxi");

var _Theme = require("../core/Theme");

var _Portal = _interopRequireDefault(require("./Portal/Portal"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const SCREEN_WIDTH = _reactNative.Dimensions.get('screen').width;

const SCREEN_HEIGHT = _reactNative.Dimensions.get('screen').height;

const Dialog = ({
  title = 'Title',
  message = 'Message',
  show = false,
  theme,
  header,
  children,
  backgroundColorOverlay = theme.colors.backdrop
}) => {
  const [state, setState] = (0, _react.useState)({
    positionView: new _reactNative.Animated.Value(SCREEN_HEIGHT),
    opacity: new _reactNative.Animated.Value(0),
    positionPopup: new _reactNative.Animated.Value(SCREEN_HEIGHT),
    popupHeight: 0,
    multipleChildren: false
  });

  function showDialog() {
    _reactNative.Animated.sequence([_reactNative.Animated.timing(state.positionView, {
      toValue: 0,
      duration: 100,
      useNativeDriver: false
    }), _reactNative.Animated.timing(state.opacity, {
      toValue: 1,
      duration: 100,
      useNativeDriver: false
    }), _reactNative.Animated.spring(state.positionPopup, {
      toValue: SCREEN_HEIGHT / 3 - state.popupHeight / 2,
      bounciness: 5,
      useNativeDriver: true
    })]).start();
  }

  function hide() {
    _reactNative.Animated.sequence([_reactNative.Animated.timing(state.positionPopup, {
      toValue: SCREEN_HEIGHT,
      duration: 200,
      useNativeDriver: true
    }), _reactNative.Animated.timing(state.opacity, {
      toValue: 0,
      duration: 200,
      useNativeDriver: false
    }), _reactNative.Animated.timing(state.positionView, {
      toValue: SCREEN_HEIGHT,
      duration: 200,
      useNativeDriver: false
    })]).start();
  }

  (0, _react.useEffect)(() => {
    if (show) {
      setState({ ...state,
        multipleChildren: _react.default.Children.count(children) >= 2
      });
      showDialog();
    } else {
      hide();
    }
  }, [show]);
  return /*#__PURE__*/_react.default.createElement(_Portal.default, null, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.container, {
      backgroundColor: backgroundColorOverlay,
      opacity: state.opacity,
      transform: [{
        translateY: state.positionView
      }]
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.dialogContainer, {
      backgroundColor: theme.colors.surface
    }, {
      transform: [{
        translateY: state.positionPopup
      }]
    }]
  }, header ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.header
  }, header) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.content, {
      marginTop: header ? 0 : '10%'
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [{
      color: theme.colors.text
    }, styles.title]
  }, title), /*#__PURE__*/_react.default.createElement(_reactNativeNoxi.SizeBox, null), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [{
      color: theme.colors.text
    }]
  }, message), /*#__PURE__*/_react.default.createElement(_reactNativeNoxi.SizeBox, null), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.dialogContent, {
      width: state.multipleChildren ? SCREEN_WIDTH / 1.8 : '100%',
      justifyContent: _reactNative.Platform.OS === 'web' && !state.multipleChildren ? 'center' : 'space-between'
    }]
  }, children)))));
};

var _default = (0, _Theme.withTheme)(Dialog);

exports.default = _default;

const styles = _reactNative.StyleSheet.create({
  container: {
    position: 'absolute',
    width: SCREEN_WIDTH,
    height: SCREEN_HEIGHT,
    alignItems: 'center'
  },
  dialogContainer: {
    maxWidth: 350,
    minWidth: 200,
    minHeight: 100,
    borderRadius: 30,
    alignItems: 'center',
    overflow: 'hidden',
    position: 'absolute'
  },
  dialogContent: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
    padding: '3%'
  },
  content: {
    alignItems: 'center',
    justifyContent: 'center',
    marginLeft: 20,
    marginRight: 20
  },
  header: {
    marginTop: 20
  },
  title: {
    fontWeight: 'bold',
    fontSize: 18
  }
});
//# sourceMappingURL=Dialog.js.map