"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _Theme = require("../core/Theme");

var _reactNativeDynamicVectorIcons = _interopRequireDefault(require("react-native-dynamic-vector-icons"));

var _Portal = _interopRequireDefault(require("./Portal/Portal"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const FAB = ({
  theme,
  type = 'small',
  icon,
  onPress,
  visible = true,
  enabled = true,
  style,
  position = 'bottom-right'
}) => {
  let fabPos = {};

  const {
    current: visibility
  } = _react.default.useRef(new _reactNative.Animated.Value(0));

  const {
    scale
  } = theme.animation;

  switch (position) {
    case 'top-left':
      fabPos = {
        top: 10,
        left: 10
      };
      break;

    case 'top-right':
      fabPos = {
        top: 10,
        right: 10
      };
      break;

    case 'bottom-left':
      fabPos = {
        bottom: 10,
        left: 10
      };
      break;

    case 'top-left':
      fabPos = {
        top: 10,
        left: 10
      };
      break;

    case 'bottom-right':
      fabPos = {
        bottom: 10,
        right: 10
      };
      break;

    default:
      fabPos = {
        bottom: 10,
        right: 10
      };
      break;
  }

  _react.default.useEffect(() => {
    if (visible) {
      _reactNative.Animated.timing(visibility, {
        toValue: 1,
        duration: 200 * scale,
        useNativeDriver: true
      }).start();
    } else {
      _reactNative.Animated.timing(visibility, {
        toValue: 0,
        duration: 100 * scale,
        useNativeDriver: true
      }).start();
    }
  }, [visible, scale, visibility]);

  return /*#__PURE__*/_react.default.createElement(_Portal.default, null, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    style: [styles[type], {
      backgroundColor: theme.colors.primary,
      opacity: visibility,
      transform: [{
        scale: visibility
      }]
    }, fabPos, style]
  }, /*#__PURE__*/_react.default.createElement(_reactNativeDynamicVectorIcons.default, {
    name: icon,
    type: theme.iconsTheme,
    size: 30,
    color: enabled ? theme.colors.buttonText : theme.colors.disabled,
    onPress: onPress
  })));
};

const styles = _reactNative.StyleSheet.create({
  small: {
    width: 60,
    height: 60,
    borderRadius: 30,
    alignItems: 'center',
    justifyContent: 'center',
    position: 'absolute'
  },
  large: {
    flex: 1,
    flexDirection: 'row',
    minWidth: 100,
    height: 60,
    borderRadius: 30,
    alignItems: 'center',
    justifyContent: 'center',
    position: 'absolute'
  }
});

var _default = (0, _Theme.withTheme)(FAB);

exports.default = _default;
//# sourceMappingURL=FAB.js.map