"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _Theme = require("../core/Theme");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const SCREEN_WIDTH = _reactNative.Dimensions.get('screen').width;

const SCREEN_HEIGHT = _reactNative.Dimensions.get('screen').height;

const ImageCard = ({
  itemHeader,
  itemBottom,
  imageStyle,
  imageBackgroundStyle,
  width = 250,
  height = 400,
  style,
  itemHeaderStyle,
  itemBottomStyle,
  automaticWidth = true,
  automaticHeight = true,
  automaticSize = true,
  backgroundOverlay = 'rgba(0,0,0,0.2)',
  theme,
  onPress
}) => {
  if (automaticSize && automaticWidth) {
    width = SCREEN_WIDTH - theme.padding;
  }

  if (automaticSize && automaticHeight) {
    height = SCREEN_HEIGHT / 4;
  }

  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    style: [styles.cardContainer, style],
    onPress: onPress
  }, /*#__PURE__*/_react.default.createElement(_reactNative.ImageBackground, {
    source: {
      uri: 'https://i1.wp.com/descubrirlahistoria.es/wp-content/uploads/2014/07/636px-Paris_July_2011-30.jpg'
    },
    resizeMode: "cover",
    style: [{
      width,
      height
    }, imageBackgroundStyle],
    imageStyle: [styles.imageBackgroundImageStyle, imageStyle]
  }, itemHeader ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.cardContentView, styles.cardContentTop, {
      backgroundColor: backgroundOverlay
    }, itemHeaderStyle]
  }, itemHeader) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null), itemBottom ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.cardContentView, styles.cardContentBottom, {
      backgroundColor: backgroundOverlay
    }, itemBottomStyle]
  }, itemBottom) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null)));
};

const styles = _reactNative.StyleSheet.create({
  imageBackgroundImageStyle: {
    borderRadius: 20,
    flex: 1,
    resizeMode: 'cover',
    justifyContent: 'center'
  },
  cardContainer: {
    flex: 1,
    flexDirection: 'column',
    padding: 28
  },
  cardContentView: {
    left: 0,
    position: 'absolute',
    right: 0,
    justifyContent: 'flex-end',
    alignItems: 'flex-start',
    padding: 8
  },
  cardContentTop: {
    top: 0,
    borderTopLeftRadius: 20,
    borderTopRightRadius: 20
  },
  cardContentBottom: {
    bottom: 0,
    marginBottom: 0,
    borderBottomLeftRadius: 20,
    borderBottomRightRadius: 20
  }
});

var _default = (0, _Theme.withTheme)(ImageCard);

exports.default = _default;
//# sourceMappingURL=ImageCard.js.map