"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.Layout = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeIphoneXHelper = require("react-native-iphone-x-helper");

var _Entry = require("./Entry");

var _reactNativeDynamicVectorIcons = _interopRequireDefault(require("react-native-dynamic-vector-icons"));

var _Theme = require("../../core/Theme");

var _TextInput = _interopRequireDefault(require("../TextInput"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const {
  height,
  width
} = _reactNative.Dimensions.get('window');

const SEARCH_BAR_HEIGHT = 40;
const containerHeight = (0, _reactNativeIphoneXHelper.ifIphoneX)(80, 20);

class Layout extends _react.PureComponent {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "state", {
      headerHeight: 0,
      headerY: 0,
      largeTitleHeight: undefined,
      isHeaderScrolled: false,
      searchBarShrinking: false,
      searchBarFixed: false
    });

    _defineProperty(this, "scrollAnimatedValue", new _reactNative.Animated.Value(0));

    _defineProperty(this, "componentDidMount", () => {
      const {
        showSearchComponent,
        showSearchComponentWithoutScroll
      } = this.props;

      if (showSearchComponent && showSearchComponentWithoutScroll) {
        setTimeout(() => {
          this.setState({
            searchBarFixed: true,
            searchBarShrinking: false
          });
        }, 100);
      } else if (showSearchComponent && !showSearchComponentWithoutScroll) {
        this.scrollAnimatedValue.addListener(value => {
          const {
            searchBarFixed
          } = this.state;
          const {
            searchBarHeight = SEARCH_BAR_HEIGHT
          } = this.props;

          if (value.value < -(searchBarHeight + styles.searchContainer.marginTop) && !searchBarFixed) {
            this.setState({
              searchBarFixed: true,
              searchBarShrinking: false
            });
          } else if (value.value > 30 && searchBarFixed) {
            this.setState({
              searchBarFixed: false,
              searchBarShrinking: true
            });
          }
        });
      }
    });

    _defineProperty(this, "onLayout", event => {
      this.setState({
        headerHeight: event.nativeEvent.layout.height,
        headerY: event.nativeEvent.layout.y
      });
    });

    _defineProperty(this, "onLargeTitleLayout", event => {
      const {
        largeTitleHeight
      } = this.state;
      const {
        searchBarHeight = 30
      } = this.props;

      if (!largeTitleHeight) {
        this.setState({
          largeTitleHeight: event.nativeEvent.layout.height - searchBarHeight + 15
        });
      }
    });

    _defineProperty(this, "handleScroll", event => {
      const {
        headerHeight,
        headerY,
        isHeaderScrolled: stateIsScrolled
      } = this.state;
      const offset = event.nativeEvent.contentOffset.y;
      const scrollHeaderOffset = headerHeight + headerY - 8;
      const isHeaderScrolled = scrollHeaderOffset < offset;

      if (!stateIsScrolled && isHeaderScrolled) {
        this.setState({
          isHeaderScrolled
        });
      }

      if (stateIsScrolled && !isHeaderScrolled) {
        this.setState({
          isHeaderScrolled
        });
      }
    });
  }

  render() {
    const {
      children,
      title = '',
      titleStyle,
      containerStyle = {},
      headerContainerStyle = {},
      headerComponentContainerStyle = {},
      headlineStyle = {},
      fadeDirection,
      scrollViewProps = {},
      searchBarHeight = SEARCH_BAR_HEIGHT,
      showSearchComponent = false,
      toolbarLeft,
      toolbarRight,
      largeToolbarRight,
      onPressBackIcon,
      canGoBack = false,
      onRefresh,
      enabledPullToRefresh = false,
      refreshing = false,
      largeToolbar = true,
      theme
    } = this.props;
    const {
      isHeaderScrolled,
      searchBarFixed,
      searchBarShrinking,
      largeTitleHeight: _largeTitleHeight
    } = this.state;
    const fontSize = titleStyle && titleStyle.fontSize ? titleStyle.fontSize : 34;
    const titleStyles = {
      fontSize,
      lineHeight: fontSize * 1.2
    };
    let margin;

    if ((0, _reactNativeIphoneXHelper.isIphoneX)()) {
      margin = (0, _reactNativeIphoneXHelper.ifIphoneX)(44, 0);
    } else {
      margin = _reactNative.StatusBar.currentHeight;
    }

    const estimatedLargeTitleHeight = titleStyles.lineHeight + margin;
    const largeTitleHeight = _largeTitleHeight || estimatedLargeTitleHeight;
    const expandedLargeTitleHeight = largeTitleHeight + searchBarHeight + styles.searchContainer.marginTop;
    const animatedFontSize = this.scrollAnimatedValue.interpolate({
      inputRange: [-height, 100],
      outputRange: [fontSize * 1.75, fontSize],
      extrapolate: 'clamp'
    });
    const animatedSearchScale = this.scrollAnimatedValue.interpolate({
      inputRange: [-searchBarHeight, 0],
      outputRange: [searchBarHeight, 0],
      extrapolate: 'clamp'
    });
    const animatedSearchScaleReverse = this.scrollAnimatedValue.interpolate({
      inputRange: [0, searchBarHeight],
      outputRange: [searchBarHeight, 0],
      extrapolate: 'clamp'
    });
    const animationLargeTitleHeight = this.scrollAnimatedValue.interpolate({
      inputRange: [-searchBarHeight, 0],
      outputRange: [expandedLargeTitleHeight, largeTitleHeight],
      extrapolate: 'clamp'
    });
    const animationLargeTitleHeightShrink = this.scrollAnimatedValue.interpolate({
      inputRange: [0, searchBarHeight],
      outputRange: [expandedLargeTitleHeight, largeTitleHeight],
      extrapolate: 'clamp'
    });
    const largeTitleAnimation = searchBarShrinking ? animationLargeTitleHeightShrink : animationLargeTitleHeight;
    const searchFieldAnimation = searchBarShrinking ? animatedSearchScaleReverse : animatedSearchScale;
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [styles.container, {
        backgroundColor: theme.colors.background
      }]
    }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [styles.headerContainerCollapse, {
        backgroundColor: theme.colors.background,
        shadowOpacity: !largeToolbar || isHeaderScrolled ? 0.2 : 0,
        elevation: !largeToolbar || isHeaderScrolled ? 8 : 0,
        height: _reactNative.Platform.OS === 'android' && isHeaderScrolled ? 50 : containerHeight
      }, headerContainerStyle]
    }, /*#__PURE__*/_react.default.createElement(_reactNative.SafeAreaView, {
      style: [styles.headerComponentContainer, headerComponentContainerStyle]
    }, !toolbarLeft && canGoBack ? /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: [styles.headerComponentLeft, {
        marginTop: _reactNative.Platform.OS === 'ios' ? 0 : 40
      }]
    }, /*#__PURE__*/_react.default.createElement(_reactNativeDynamicVectorIcons.default, {
      name: "arrow-back",
      type: "ionicons",
      size: 28,
      color: theme.colors.text,
      onPress: onPressBackIcon
    })) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.headerComponentLeft
    }, toolbarLeft), /*#__PURE__*/_react.default.createElement(_Entry.Entry, {
      style: styles.headerComponentMain,
      visible: largeToolbar ? isHeaderScrolled : true,
      direction: fadeDirection
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: [styles.headline, {
        color: theme.colors.text
      }, headlineStyle]
    }, title)), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: styles.headerComponentRight
    }, toolbarRight), /*#__PURE__*/_react.default.createElement(_reactNative.View, null))), /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, _extends({
      renderItem: null,
      overScrollMode: "never",
      nestedScrollEnabled: true,
      style: {
        flex: 1
      },
      onScroll: _reactNative.Animated.event([{
        nativeEvent: {
          contentOffset: {
            y: this.scrollAnimatedValue
          }
        }
      }], {
        listener: this.handleScroll,
        useNativeDriver: false
      }),
      scrollEventThrottle: 8,
      refreshControl: // only enabled={enabledPullToRefresh} not work in 0.63
      enabledPullToRefresh ? /*#__PURE__*/_react.default.createElement(_reactNative.RefreshControl, {
        enabled: enabledPullToRefresh,
        refreshing: refreshing,
        onRefresh: onRefresh,
        tintColor: theme.colors.text
      }) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null)
    }, scrollViewProps, {
      data: [],
      ListHeaderComponent: /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, largeToolbar ? /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
        style: [showSearchComponent ? {
          height: searchBarFixed ? expandedLargeTitleHeight : largeTitleAnimation
        } : {
          flex: 1,
          flexDirection: 'row'
        }],
        onLayout: this.onLargeTitleLayout
      }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
        style: styles.scroll
      }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.Text, {
        style: [{
          fontSize: animatedFontSize,
          color: theme.colors.text
        }, styles.title, titleStyles, titleStyle],
        onLayout: this.onLayout
      }, title)), showSearchComponent ? /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
        style: [styles.searchContainer, {
          height: searchBarFixed ? searchBarHeight : searchFieldAnimation
        }]
      }, /*#__PURE__*/_react.default.createElement(_Entry.Entry, {
        visible: searchBarFixed
      }, /*#__PURE__*/_react.default.createElement(_TextInput.default, {
        placeholder: "Search",
        iconLeftName: "search1",
        style: {
          height: searchBarHeight
        }
      }))) : null, largeToolbarRight) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null)),
      ListFooterComponent: /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
        style: [styles.children, containerStyle]
      }, children)
    })));
  }

}

exports.Layout = Layout;

_defineProperty(Layout, "defaultProps", {
  scrollViewProps: {},
  searchBarHeight: SEARCH_BAR_HEIGHT,
  showSearchComponent: false,
  showSearchComponentWithoutScroll: false,
  ScrollComponent: _reactNative.ScrollView
});

const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: 'transparent',
    marginTop: _reactNative.Platform.OS === 'android' ? _reactNative.StatusBar.currentHeight : 0
  },
  headerContainer: {
    height: containerHeight
  },
  headerContainerCollapse: {
    elevation: 0,
    shadowColor: '#000000',
    shadowOffset: {
      width: 0,
      height: 2
    },
    shadowRadius: 4
  },
  headerComponentContainer: {
    height: containerHeight,
    alignItems: 'center',
    justifyContent: 'space-between',
    flexDirection: 'row',
    paddingBottom: 12
  },
  headerComponentLeft: {
    flex: 1,
    marginLeft: 20,
    justifyContent: 'center',
    alignItems: 'flex-start'
  },
  headerComponentRight: {
    flex: 1,
    marginRight: 20,
    justifyContent: 'center',
    alignItems: 'flex-end'
  },
  largeHeaderComponentRight: {
    flex: 1,
    marginRight: 10,
    justifyContent: 'center',
    alignItems: 'flex-end'
  },
  headerComponentMain: {
    justifyContent: 'center',
    alignItems: 'center'
  },
  headline: {
    fontSize: 17,
    lineHeight: 22,
    fontWeight: '500',
    letterSpacing: 0.2,
    marginLeft: -width / 24,
    marginTop: _reactNative.Platform.OS === 'android' ? 50 : undefined
  },
  title: {
    letterSpacing: 0.011,
    fontWeight: '700'
  },
  scroll: {
    flex: 1,
    flexDirection: 'row',
    marginLeft: 20,
    marginRight: 20
  },
  searchContainer: {
    marginTop: 0,
    marginBottom: 10,
    marginLeft: 20,
    marginRight: 20
  },
  children: {
    flex: 1
  },
  defaultButton: {
    color: 'blue'
  }
});

var _default = (0, _Theme.withTheme)(Layout);

exports.default = _default;
//# sourceMappingURL=Layout.js.map