"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _Theme = require("../../core/Theme");

var _Portal = _interopRequireDefault(require("../Portal/Portal"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/* eslint-disable @typescript-eslint/no-unused-vars */
const SCREEN_WIDTH = _reactNative.Dimensions.get('screen').width;

const SCREEN_HEIGHT = _reactNative.Dimensions.get('screen').height;

const Select = ({
  show = false,
  theme,
  xPos = 0,
  yPos = 0,
  children,
  onClose,
  backgroundColorOverlay = theme.colors.backdrop
}) => {
  const [state, setState] = (0, _react.useState)({
    positionView: new _reactNative.Animated.Value(yPos),
    opacity: new _reactNative.Animated.Value(0),
    positionPopup: new _reactNative.Animated.Value(xPos - yPos),
    positionX: xPos,
    positionY: yPos,
    popupHeight: 0,
    multipleChildren: false
  });

  function showSelect() {
    _reactNative.Animated.sequence([_reactNative.Animated.timing(state.positionView, {
      toValue: 0,
      duration: 100,
      useNativeDriver: false
    }), _reactNative.Animated.timing(state.opacity, {
      toValue: 1,
      duration: 100,
      useNativeDriver: false
    }), _reactNative.Animated.spring(state.positionPopup, {
      toValue: xPos + yPos,
      bounciness: 5,
      useNativeDriver: true
    })]).start();
  }

  function hide() {
    _reactNative.Animated.sequence([_reactNative.Animated.timing(state.positionPopup, {
      toValue: SCREEN_HEIGHT,
      duration: 100,
      useNativeDriver: true
    }), _reactNative.Animated.timing(state.opacity, {
      toValue: 0,
      duration: 100,
      useNativeDriver: false
    }), _reactNative.Animated.timing(state.positionView, {
      toValue: SCREEN_HEIGHT,
      duration: 100,
      useNativeDriver: false
    })]).start();
  }

  (0, _react.useEffect)(() => {
    if (show) {
      showSelect();
    } else {
      hide();
    }
  }, [show]);
  (0, _react.useEffect)(() => {
    setState({ ...state,
      positionX: xPos,
      positionY: yPos
    });
  }, [xPos, yPos]);
  return /*#__PURE__*/_react.default.createElement(_Portal.default, null, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
    onPress: onClose
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.container, {
      backgroundColor: backgroundColorOverlay,
      opacity: state.opacity,
      transform: [{
        translateY: state.positionView
      }]
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [styles.SelectContainer, {
      backgroundColor: theme === null || theme === void 0 ? void 0 : theme.colors.surface
    }, {
      transform: [{
        translateY: state.positionY
      }, {
        translateX: state.positionX
      }]
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.content
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.SelectContent]
  }, children))))));
};

const styles = _reactNative.StyleSheet.create({
  container: {
    position: 'absolute',
    zIndex: 99999,
    width: SCREEN_WIDTH,
    height: SCREEN_HEIGHT,
    alignItems: 'center',
    top: 0,
    left: 0
  },
  SelectContainer: {
    borderRadius: 15,
    overflow: 'hidden',
    position: 'absolute'
  },
  SelectContent: {
    flex: 1,
    padding: 10
  },
  content: {
    alignItems: 'center',
    flexDirection: 'column'
  }
});

var _default = (0, _Theme.withTheme)(Select);

exports.default = _default;
//# sourceMappingURL=Select.js.map