import React from 'react';
import { Text, View, TouchableOpacity } from 'react-native';
import { withTheme } from '../core/Theme';
import Icon from 'react-native-dynamic-vector-icons';

const Chip = ({
  children,
  type = 'round',
  onPress,
  icon,
  theme,
  itemLeft,
  itemRight,
  textStyle,
  style,
  iconStyle,
  iconSize,
  disabled
}) => {
  const chipContentStyle = {
    flexDirection: 'row',
    backgroundColor: theme.colors.primary,
    padding: 4
  };
  const defaultTextStyle = {
    color: theme.colors.buttonText,
    letterSpacing: 0.3,
    fontSize: 12,
    margin: 5
  };

  if (type === 'round') {
    chipContentStyle.borderRadius = 100;
  }

  if (type === 'square') {
    chipContentStyle.borderRadius = 10;
  }

  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onPress,
    disabled: disabled
  }, /*#__PURE__*/React.createElement(View, {
    style: [chipContentStyle, style]
  }, icon ? /*#__PURE__*/React.createElement(Icon, {
    name: icon,
    type: theme.iconsTheme,
    size: iconSize || 25,
    style: iconStyle,
    color: theme.colors.buttonText
  }) : /*#__PURE__*/React.createElement(React.Fragment, null, itemLeft), /*#__PURE__*/React.createElement(Text, {
    style: [defaultTextStyle, textStyle]
  }, children), itemRight));
};

export default withTheme(Chip);
//# sourceMappingURL=Chip.js.map