import React, { useEffect, useState } from 'react';
import { View, Text, StyleSheet, Animated, Dimensions, Platform } from 'react-native';
import { SizeBox } from 'react-native-noxi';
import { withTheme } from '../core/Theme';
import Portal from './Portal/Portal';
const SCREEN_WIDTH = Dimensions.get('screen').width;
const SCREEN_HEIGHT = Dimensions.get('screen').height;

const Dialog = ({
  title = 'Title',
  message = 'Message',
  show = false,
  theme,
  header,
  children,
  backgroundColorOverlay = theme.colors.backdrop
}) => {
  const [state, setState] = useState({
    positionView: new Animated.Value(SCREEN_HEIGHT),
    opacity: new Animated.Value(0),
    positionPopup: new Animated.Value(SCREEN_HEIGHT),
    popupHeight: 0,
    multipleChildren: false
  });

  function showDialog() {
    Animated.sequence([Animated.timing(state.positionView, {
      toValue: 0,
      duration: 100,
      useNativeDriver: false
    }), Animated.timing(state.opacity, {
      toValue: 1,
      duration: 100,
      useNativeDriver: false
    }), Animated.spring(state.positionPopup, {
      toValue: SCREEN_HEIGHT / 3 - state.popupHeight / 2,
      bounciness: 5,
      useNativeDriver: true
    })]).start();
  }

  function hide() {
    Animated.sequence([Animated.timing(state.positionPopup, {
      toValue: SCREEN_HEIGHT,
      duration: 200,
      useNativeDriver: true
    }), Animated.timing(state.opacity, {
      toValue: 0,
      duration: 200,
      useNativeDriver: false
    }), Animated.timing(state.positionView, {
      toValue: SCREEN_HEIGHT,
      duration: 200,
      useNativeDriver: false
    })]).start();
  }

  useEffect(() => {
    if (show) {
      setState({ ...state,
        multipleChildren: React.Children.count(children) >= 2
      });
      showDialog();
    } else {
      hide();
    }
  }, [show]);
  return /*#__PURE__*/React.createElement(Portal, null, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.container, {
      backgroundColor: backgroundColorOverlay,
      opacity: state.opacity,
      transform: [{
        translateY: state.positionView
      }]
    }]
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.dialogContainer, {
      backgroundColor: theme.colors.surface
    }, {
      transform: [{
        translateY: state.positionPopup
      }]
    }]
  }, header ? /*#__PURE__*/React.createElement(View, {
    style: styles.header
  }, header) : /*#__PURE__*/React.createElement(React.Fragment, null), /*#__PURE__*/React.createElement(View, {
    style: [styles.content, {
      marginTop: header ? 0 : '10%'
    }]
  }, /*#__PURE__*/React.createElement(Text, {
    style: [{
      color: theme.colors.text
    }, styles.title]
  }, title), /*#__PURE__*/React.createElement(SizeBox, null), /*#__PURE__*/React.createElement(Text, {
    style: [{
      color: theme.colors.text
    }]
  }, message), /*#__PURE__*/React.createElement(SizeBox, null), /*#__PURE__*/React.createElement(View, {
    style: [styles.dialogContent, {
      width: state.multipleChildren ? SCREEN_WIDTH / 1.8 : '100%',
      justifyContent: Platform.OS === 'web' && !state.multipleChildren ? 'center' : 'space-between'
    }]
  }, children)))));
};

export default withTheme(Dialog);
const styles = StyleSheet.create({
  container: {
    position: 'absolute',
    width: SCREEN_WIDTH,
    height: SCREEN_HEIGHT,
    alignItems: 'center'
  },
  dialogContainer: {
    maxWidth: 350,
    minWidth: 200,
    minHeight: 100,
    borderRadius: 30,
    alignItems: 'center',
    overflow: 'hidden',
    position: 'absolute'
  },
  dialogContent: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
    padding: '3%'
  },
  content: {
    alignItems: 'center',
    justifyContent: 'center',
    marginLeft: 20,
    marginRight: 20
  },
  header: {
    marginTop: 20
  },
  title: {
    fontWeight: 'bold',
    fontSize: 18
  }
});
//# sourceMappingURL=Dialog.js.map