import React from 'react';
import { TouchableOpacity, StyleSheet, Animated } from 'react-native';
import { withTheme } from '../core/Theme';
import Icon from 'react-native-dynamic-vector-icons';
import Portal from './Portal/Portal';

const FAB = ({
  theme,
  type = 'small',
  icon,
  onPress,
  visible = true,
  enabled = true,
  style,
  position = 'bottom-right'
}) => {
  let fabPos = {};
  const {
    current: visibility
  } = React.useRef(new Animated.Value(0));
  const {
    scale
  } = theme.animation;

  switch (position) {
    case 'top-left':
      fabPos = {
        top: 10,
        left: 10
      };
      break;

    case 'top-right':
      fabPos = {
        top: 10,
        right: 10
      };
      break;

    case 'bottom-left':
      fabPos = {
        bottom: 10,
        left: 10
      };
      break;

    case 'top-left':
      fabPos = {
        top: 10,
        left: 10
      };
      break;

    case 'bottom-right':
      fabPos = {
        bottom: 10,
        right: 10
      };
      break;

    default:
      fabPos = {
        bottom: 10,
        right: 10
      };
      break;
  }

  React.useEffect(() => {
    if (visible) {
      Animated.timing(visibility, {
        toValue: 1,
        duration: 200 * scale,
        useNativeDriver: true
      }).start();
    } else {
      Animated.timing(visibility, {
        toValue: 0,
        duration: 100 * scale,
        useNativeDriver: true
      }).start();
    }
  }, [visible, scale, visibility]);
  return /*#__PURE__*/React.createElement(Portal, null, /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: [styles[type], {
      backgroundColor: theme.colors.primary,
      opacity: visibility,
      transform: [{
        scale: visibility
      }]
    }, fabPos, style]
  }, /*#__PURE__*/React.createElement(Icon, {
    name: icon,
    type: theme.iconsTheme,
    size: 30,
    color: enabled ? theme.colors.buttonText : theme.colors.disabled,
    onPress: onPress
  })));
};

const styles = StyleSheet.create({
  small: {
    width: 60,
    height: 60,
    borderRadius: 30,
    alignItems: 'center',
    justifyContent: 'center',
    position: 'absolute'
  },
  large: {
    flex: 1,
    flexDirection: 'row',
    minWidth: 100,
    height: 60,
    borderRadius: 30,
    alignItems: 'center',
    justifyContent: 'center',
    position: 'absolute'
  }
});
export default withTheme(FAB);
//# sourceMappingURL=FAB.js.map