import React, { useState } from 'react';
import { StyleSheet, View, Animated } from 'react-native';

const Image = ({
  onloadPlaceholder,
  onLoadImage,
  placeholderFadeDuration = 350,
  imageFadeDuration = 350,
  placeholderBlurRadius = 20,
  placeHolderSource,
  imageSource,
  imageStyle,
  style,
  resizeMode = 'cover'
}) => {
  const [state] = useState({
    imageOpacity: new Animated.Value(0),
    placeholderOpacity: new Animated.Value(0)
  });

  function loadPlaceholder() {
    Animated.timing(state.placeholderOpacity, {
      toValue: 1,
      duration: placeholderFadeDuration,
      useNativeDriver: true
    }).start();
    onloadPlaceholder;
  }

  function loadImage() {
    Animated.timing(state.imageOpacity, {
      toValue: 1,
      duration: imageFadeDuration,
      useNativeDriver: true
    }).start();
    onLoadImage;
  }

  return /*#__PURE__*/React.createElement(View, {
    style: style
  }, placeHolderSource ? /*#__PURE__*/React.createElement(Animated.Image, {
    resizeMode: resizeMode,
    style: [styles.image, {
      opacity: state.placeholderOpacity
    }, imageStyle],
    source: placeHolderSource,
    onLoad: loadPlaceholder,
    blurRadius: placeholderBlurRadius
  }) : /*#__PURE__*/React.createElement(React.Fragment, null), /*#__PURE__*/React.createElement(Animated.Image, {
    resizeMode: resizeMode,
    style: [styles.image, {
      opacity: state.imageOpacity
    }, imageStyle],
    source: imageSource,
    onLoad: loadImage
  }));
};

const styles = StyleSheet.create({
  image: {
    position: 'absolute',
    top: 0,
    bottom: 0,
    left: 0,
    right: 0
  }
});
export default Image;
//# sourceMappingURL=Image.js.map