import React from 'react';
import { StyleSheet, TextInput as TI, View } from 'react-native';
import { withTheme } from '../core/Theme';
import Icon from 'react-native-dynamic-vector-icons';

const TextInput = ({
  theme,
  onChange,
  onChangeText,
  onBlur,
  placeholder,
  value,
  secureTextEntry,
  onPressRigthIcon,
  onPressLeftIcon,
  iconLeftName,
  iconRightName,
  styleText,
  style,
  editable = true
}) => {
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.sectionStyle, {
      backgroundColor: theme.colors.surface,
      borderWidth: 0.5,
      borderColor: editable ? theme.colors.primary : theme.colors.disabled
    }, style]
  }, iconLeftName ? /*#__PURE__*/React.createElement(Icon, {
    name: iconLeftName,
    style: styles.iconStyle,
    type: theme.iconsTheme,
    size: 30,
    color: editable ? theme.colors.primary : theme.colors.disabled,
    onPress: onPressLeftIcon
  }) : /*#__PURE__*/React.createElement(React.Fragment, null), /*#__PURE__*/React.createElement(TI, {
    onChange: onChange,
    onBlur: onBlur,
    editable: editable,
    placeholder: placeholder,
    onChangeText: onChangeText,
    secureTextEntry: secureTextEntry,
    selectionColor: theme.colors.primary,
    placeholderTextColor: editable ? theme.colors.primary : theme.colors.disabled,
    style: [{
      flex: 1,
      marginLeft: 5,
      marginRight: 5,
      color: theme.colors.text
    }, styleText],
    value: value
  }), iconRightName ? /*#__PURE__*/React.createElement(Icon, {
    name: iconRightName,
    type: theme.iconsTheme,
    style: styles.iconStyle,
    size: 30,
    color: editable ? theme.colors.primary : theme.colors.disabled,
    onPress: onPressRigthIcon
  }) : /*#__PURE__*/React.createElement(React.Fragment, null));
};

export default withTheme(TextInput);
const styles = StyleSheet.create({
  iconStyle: {
    padding: '1%'
  },
  sectionStyle: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    borderRadius: 5
  }
});
//# sourceMappingURL=TextInput.js.map